==> pdfhandoutcrop-0.2.1-py3-none-any.whl: pdfhandoutcrop/language/pdfhandoutcrop_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>PdfHandoutCrop</source>
        <translation>PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Auto detect</source>
        <translation>自動偵測(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Pages per sheet:</source>
        <translation>每張紙的頁數：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Zoom &amp;out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Width and Height</source>
        <translation>寬和高</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Click to set</source>
        <translation>按一下來設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Position:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>&amp;Convert</source>
        <translation>轉換(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>About &amp;Qt</source>
        <translation>關於 &amp;Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="45"/>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF 文件 (*.pdf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="40"/>
        <source>{0} - PdfHandoutCrop</source>
        <translation>{0} - PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="58"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="76"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="234"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="80"/>
        <source>Cannot open input file</source>
        <translation>無法開啟輸入檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="125"/>
        <source>Cannot find a page</source>
        <translation>無法找到頁面</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="187"/>
        <source>Found {0} pages</source>
        <translation>找到 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="222"/>
        <source>Please click the upper left point of page {0}</source>
        <translation>請按一下第 {0} 頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="228"/>
        <source>Please click the upper left point of any page</source>
        <translation>請按一下任何一頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="234"/>
        <source>Height should be set first</source>
        <translation>應該要先設定高度</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="253"/>
        <source>Please click the lower right point of the page you clicked</source>
        <translation>請按一下你剛剛按的那一頁的右下角</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Previous</source>
        <comment>previous page</comment>
        <translation>上一頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>&amp;Next</source>
        <comment>next page</comment>
        <translation>下一頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="19"/>
        <source>Page {0}</source>
        <translation>第 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="118"/>
        <source>Finished</source>
        <translation>已完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="118"/>
        <source>Convert finished</source>
        <translation>轉換已完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>x:</source>
        <comment>x coordinate</comment>
        <translation>x:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>y:</source>
        <comment>y coordinate</comment>
        <translation>y:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>&amp;Reload</source>
        <translation>重新載入(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="57"/>
        <source>&lt;h3&gt;PdfHandoutCrop&lt;/h3&gt;&lt;br&gt;
Author: Hsiu-Ming Chang&lt;br&gt;
e-mail: cges30901@gmail.com&lt;br&gt;
License: GPL v3</source>
        <translation type="obsolete">&lt;h3&gt;PdfHandoutCrop&lt;/h3&gt;&lt;br&gt;
作者：張修銘&lt;br&gt;
電子郵件：cges30901@gmail.com&lt;br&gt;
授權：GPL v3</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="58"/>
        <source>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
Author: Hsiu-Ming Chang&lt;br&gt;
e-mail: cges30901@gmail.com&lt;br&gt;
License: GPL v3</source>
        <translation type="unfinished">&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
作者：張修銘&lt;br&gt;
電子郵件：cges30901@gmail.com&lt;br&gt;
授權：GPL v3</translation>
    </message>
</context>
<context>
    <name>SetPagesDialog</name>
    <message>
        <location filename="../setpagesdialog.ui" line="20"/>
        <source>Only one page is detected. Please select layout</source>
        <translation>只偵測到一頁。請選擇版面配置</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="29"/>
        <source>Columns:</source>
        <translation>欄：</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="60"/>
        <source>Rows:</source>
        <translation>列：</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="117"/>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="14"/>
        <source>Select layout</source>
        <translation>選擇版面配置</translation>
    </message>
</context>
</TS>

==> pdfhandoutcrop-0.3.1-py3-none-any.whl: pdfhandoutcrop/language/pdfhandoutcrop_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>PdfHandoutCrop</source>
        <translation>PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Auto detect</source>
        <translation>自動偵測(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Pages per sheet:</source>
        <translation>每張紙的頁數：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Zoom &amp;out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Width and Height</source>
        <translation>寬和高</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Click to set</source>
        <translation>按一下來設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Position:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>&amp;Convert</source>
        <translation>轉換(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>About &amp;Qt</source>
        <translation>關於 &amp;Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="45"/>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF 文件 (*.pdf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="40"/>
        <source>{0} - PdfHandoutCrop</source>
        <translation>{0} - PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="58"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="76"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="266"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="80"/>
        <source>Cannot open input file</source>
        <translation>無法開啟輸入檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="219"/>
        <source>Found {0} pages</source>
        <translation>找到 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="254"/>
        <source>Please click the upper left point of page {0}</source>
        <translation>請按一下第 {0} 頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="260"/>
        <source>Please click the upper left point of any page</source>
        <translation>請按一下任何一頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="266"/>
        <source>Height should be set first</source>
        <translation>應該要先設定高度</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="285"/>
        <source>Please click the lower right point of the page you clicked</source>
        <translation>請按一下你剛剛按的那一頁的右下角</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Previous</source>
        <comment>previous page</comment>
        <translation>上一頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>&amp;Next</source>
        <comment>next page</comment>
        <translation>下一頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="67"/>
        <source>Page {0}</source>
        <translation>第 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="149"/>
        <source>Finished</source>
        <translation>已完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="149"/>
        <source>Convert finished</source>
        <translation>轉換已完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>x:</source>
        <comment>x coordinate</comment>
        <translation>x:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>y:</source>
        <comment>y coordinate</comment>
        <translation>y:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>&amp;Reload</source>
        <translation>重新載入(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="58"/>
        <source>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
Author: Hsiu-Ming Chang&lt;br&gt;
e-mail: cges30901@gmail.com&lt;br&gt;
License: GPL v3</source>
        <translation>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
作者：張修銘&lt;br&gt;
電子郵件：cges30901@gmail.com&lt;br&gt;
授權：GPL v3</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="156"/>
        <source>Page can not be found</source>
        <translation>無法找到頁面</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="156"/>
        <source>Page can not be found. Auto detect only works if pages have border.</source>
        <translation>無法找到頁面。自動偵測只有在頁面有框線時才能運作。</translation>
    </message>
</context>
<context>
    <name>SetPagesDialog</name>
    <message>
        <location filename="../setpagesdialog.ui" line="20"/>
        <source>Only one page is detected. Please select layout</source>
        <translation>只偵測到一頁。請選擇版面配置</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="29"/>
        <source>Columns:</source>
        <translation>欄：</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="60"/>
        <source>Rows:</source>
        <translation>列：</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="117"/>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="14"/>
        <source>Select layout</source>
        <translation>選擇版面配置</translation>
    </message>
</context>
</TS>
